@@ -32,6 +32,13 @@
 # define FALSE	(1==0)
 #endif
 
+#if !defined(IRQF_SHARED)
+#define IRQF_SHARED SA_SHIRQ
+#endif
+#if !defined(IRQF_DISABLED)
+#define IRQF_DISABLED SA_INTERRUPT
+#endif
+
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
 #if defined (__fcclassic__)
@@ -54,7 +61,7 @@
 #define DRIVER_LOGO		PRODUCT_LOGO " driver"
 #define	DRIVER_TYPE_INTERN
 #define	DRIVER_TYPE_ISDN
-#define	DRIVER_REV		"0.7.1"
+#define	DRIVER_REV		"0.8.0"
 
 /*---------------------------------------------------------------------------*\
 \*---------------------------------------------------------------------------*/
