@@ -198,7 +198,7 @@ static void copy_version (struct capi_ctr * ctrl) {
 	}
 	lib_strncpy (ctrl->serial, tmp, CAPI_SERIAL_LEN);
 	lib_memcpy (&ctrl->profile, card->string[6], sizeof (capi_profile));
-	strncpy (ctrl->manu, "AVM GmbH", CAPI_MANUFACTURER_LEN);
+	lib_strncpy (ctrl->manu, "AVM GmbH", CAPI_MANUFACTURER_LEN);
 	ctrl->version.majorversion = 2;
 	ctrl->version.minorversion = 0;
 	tmp = card->string[0];
@@ -371,16 +371,20 @@ static int install_card (card_t * card) {
 		return FALSE;
 	}
 #endif
+#ifdef __LP64__
+	card->data = (unsigned long) &irq_handler;
+#else
 	card->data = (unsigned) &irq_handler;
+#endif
 	tasklet_init (&scheduler_tasklet, scheduler, 0);
 	disable_scheduler ();
 	result = request_irq (
 			card->irq, 
 			&irq_handler, 
 #if defined (__fcpci__) || defined (__fcpcmcia__)
-			SA_INTERRUPT | SA_SHIRQ, 
+			IRQF_DISABLED | IRQF_SHARED, 
 #else
-			SA_INTERRUPT, 
+			IRQF_DISABLED, 
 #endif
 			TARGET, 
 			card
