@@ -362,8 +362,12 @@ static int __init fritz_init (void) {
 	NOTE("-- 32 bit CAPI driver --\n");
 #endif
 
-#if defined (__fcpci__)	
+#if defined (__fcpci__)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,22)
 	if (0 == (err = pci_module_init (&fcpci_driver))) {
+#else
+	if (0 == (err = pci_register_driver (&fcpci_driver))) {
+#endif
 		LOG("PCI driver registered.\n");
 		register_capi_driver (&fritz_capi_driver);
 		LOG("CAPI driver registered.\n");
